@@ -97,7 +97,8 @@ class Model(ABC, Optionizable):
         pass
 
     def prepareData(self, dataset: DataSet, validation=False):
-        return self.prepareX(dataset.x), self.prepareY(dataset.y)
+        x, y = dataset
+        return self.prepareX(x), self.prepareY(y)
 
     def prepareX(self, x, validation=False):
         return x
